'use strict';

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _chai = require('chai');

var _mochaJsdom = require('mocha-jsdom');

var _mochaJsdom2 = _interopRequireDefault(_mochaJsdom);

var _lodashObjectOmit = require('lodash/object/omit');

var _lodashObjectOmit2 = _interopRequireDefault(_lodashObjectOmit);

var _ = require('../');

var _utils = require('./utils');

var _reactAddonsTestUtils = require('react-addons-test-utils');

describe('withState()', function () {
  (0, _mochaJsdom2['default'])();

  var Counter = (0, _.withState)('counter', 'updateCounter', 0)(_utils.BaseComponent);

  it('adds a stateful value and a function for updating it', function () {
    (0, _chai.expect)(Counter.displayName).to.equal('withState(BaseComponent)');

    var tree = (0, _reactAddonsTestUtils.renderIntoDocument)(_react2['default'].createElement(Counter, { pass: 'through' }));
    var base = (0, _reactAddonsTestUtils.findRenderedComponentWithType)(tree, _utils.BaseComponent);

    (0, _chai.expect)((0, _lodashObjectOmit2['default'])(base.props, 'updateCounter')).to.eql({
      counter: 0,
      pass: 'through'
    });

    base.props.updateCounter(function (n) {
      return n + 9;
    });
    base.props.updateCounter(function (n) {
      return n * 2;
    });
    (0, _chai.expect)((0, _lodashObjectOmit2['default'])(base.props, 'updateCounter')).to.eql({
      counter: 18,
      pass: 'through'
    });
  });

  it('also accepts a non-function, which is passed directly to setState()', function () {
    var tree = (0, _reactAddonsTestUtils.renderIntoDocument)(_react2['default'].createElement(Counter, { pass: 'through' }));
    var base = (0, _reactAddonsTestUtils.findRenderedComponentWithType)(tree, _utils.BaseComponent);

    base.props.updateCounter(18);
    (0, _chai.expect)((0, _lodashObjectOmit2['default'])(base.props, 'updateCounter')).to.eql({
      counter: 18,
      pass: 'through'
    });
  });
});